@@ -12,8 +12,9 @@ from nonebot_plugin_mahjong_scoreboard.controller.general_handlers import requir
     require_game_code_from_context, require_parse_unary_integer_arg
 from nonebot_plugin_mahjong_scoreboard.controller.interceptor import general_interceptor
 from nonebot_plugin_mahjong_scoreboard.controller.mapper.game_mapper import map_game
-from nonebot_plugin_mahjong_scoreboard.controller.utils import parse_int_or_error, try_parse_wind, \
-    parse_float_or_error, SplitCommandArgs
+from nonebot_plugin_mahjong_scoreboard.controller.utils.message import SplitCommandArgs
+from nonebot_plugin_mahjong_scoreboard.controller.utils.parse import parse_int_or_error, try_parse_wind, \
+    parse_float_or_error
 from nonebot_plugin_mahjong_scoreboard.errors import BadRequestError
 from nonebot_plugin_mahjong_scoreboard.model.enums import PlayerAndWind, GameState
 from nonebot_plugin_mahjong_scoreboard.service import game_service, group_service, user_service
@@ -260,7 +261,7 @@ async def parse_make_game_progress_args(matcher: Matcher, args: Message = SplitC
             text = arg.data["text"]
             if text.startswith("对局"):
                 game_code = parse_int_or_error(text[len("对局"):], '对局编号')
-            elif text == '完成':
+            elif text == '完成' or text == '已完成':
                 completed = True
             else:
                 match_result = re.match(round_honba_pattern, text)
@@ -275,6 +276,8 @@ async def parse_make_game_progress_args(matcher: Matcher, args: Message = SplitC
 
     if game_code is None:
         raise BadRequestError("请指定对局编号")
+    if not completed and (round is None or honba is None):
+        raise BadRequestError("请指定对局进度（”东/南x局y本场“或”完成“）")
 
     matcher.state["game_code"] = game_code
     matcher.state["completed"] = completed
