@@ -47,3 +47,12 @@ def map_datetime(dt: datetime):
 
 def percentile_str(x: float, ndigits: int = 2) -> str:
     return f'{round(x * 100, ndigits)}%'
+
+
+def map_point(raw_point: int, scale: int) -> str:
+    point_text = f"%.{-scale}f" % (raw_point * 10 ** scale)
+    if raw_point > 0:
+        point_text = f'+{point_text}'
+    elif raw_point == 0:
+        point_text = f'±{point_text}'
+    return point_text
