@@ -2,8 +2,9 @@ from datetime import datetime
 from operator import and_
 from typing import Optional, List, Literal, overload, Tuple, Union
 
+from sqlalchemy import delete
 from sqlalchemy.future import select
-from sqlalchemy.sql.functions import count
+from sqlalchemy.sql.functions import count, func
 
 from nonebot_plugin_mahjong_scoreboard.errors import BadRequestError
 from nonebot_plugin_mahjong_scoreboard.model.enums import SeasonUserPointChangeType
@@ -74,7 +75,7 @@ async def get_season_user_point_change_logs(season: Optional[SeasonOrm] = None,
         stmt = stmt.where(SeasonUserPointChangeLogOrm.season == season)
 
     if user is not None:
-        stmt.append_whereclause(SeasonUserPointChangeLogOrm.user == user)
+        stmt = stmt.where(SeasonUserPointChangeLogOrm.user == user)
 
     if reverse_order:
         stmt = stmt.order_by(SeasonUserPointChangeLogOrm.id.desc())
@@ -119,6 +120,29 @@ async def count_season_user_point(season: SeasonOrm) -> Optional[SeasonUserPoint
     return result
 
 
+async def reset_season_user_point(season: SeasonOrm,
+                                  user: UserOrm,
+                                  operator: UserOrm):
+    session = data_source.session()
+
+    group = await session.get(GroupOrm, season.group_id)
+    if not await is_group_admin(operator, group):
+        raise BadRequestError("没有权限")
+
+    sup = await get_season_user_point(season, user)
+    if sup is None:
+        return
+
+    stmt = delete(SeasonUserPointChangeLogOrm).where(
+        SeasonUserPointChangeLogOrm.season_id == sup.season_id,
+        SeasonUserPointChangeLogOrm.user_id == sup.user_id
+    )
+    await session.execute(stmt)
+
+    await session.delete(sup)
+    await session.commit()
+
+
 async def change_season_user_point_manually(season: SeasonOrm,
                                             user: UserOrm,
                                             point: float,
@@ -148,7 +172,7 @@ async def change_season_user_point_manually(season: SeasonOrm,
 async def change_season_user_point_by_game(game: GameOrm):
     session = data_source.session()
 
-    for rank, r in ranked(game.records, key=lambda r: r.point, reverse=True):
+    for rank, r in ranked(game.records, key=lambda r: r.raw_point, reverse=True):
         # 记录SeasonUserPoint
         stmt = select(SeasonUserPointOrm).where(
             SeasonUserPointOrm.season_id == game.season_id,
@@ -162,68 +186,19 @@ async def change_season_user_point_by_game(game: GameOrm):
                                             point=0)
             session.add(user_point)
 
-        user_point.point += r.point
+        user_point.point += r.raw_point
 
         # 记录SeasonUserPointChangeLog
         change_log = SeasonUserPointChangeLogOrm(user_id=r.user_id,
                                                  season_id=game.season_id,
                                                  change_type=SeasonUserPointChangeType.game,
-                                                 change_point=r.point,
+                                                 change_point=r.raw_point,
                                                  related_game_id=game.id)
         session.add(change_log)
 
     await session.commit()
 
 
-# async def revert_season_user_point_manually(season: SeasonOrm,
-#                                             user: UserOrm,
-#                                             operator: UserOrm) -> bool:
-#     session = data_source.session()
-#     group = await session.get(GroupOrm, season.group_id)
-#     if not await is_group_admin(operator, group):
-#         raise BadRequestError("没有权限")
-#
-#     stmt = select(SeasonUserPointChangeLogOrm).where(
-#         SeasonUserPointChangeLogOrm.season_id == season.id,
-#         SeasonUserPointChangeLogOrm.user_id == user.id
-#     ).order_by(
-#         SeasonUserPointChangeLogOrm.create_time.desc()
-#     ).limit(2)
-#
-#     result = await session.scalars(stmt)
-#     if len(result) == 0:
-#         return False
-#     else:
-#         log: SeasonUserPointChangeLogOrm = result[0]
-#         prev_log: SeasonUserPointChangeLogOrm = result[1] if len(result) >= 2 else None
-#
-#         if log.change_type != SeasonUserPointChangeType.manually \
-#                 or datetime.utcnow() - log.create_time > timedelta(days=1):
-#             return False
-#
-#         stmt = delete(SeasonUserPointChangeLogOrm).where(
-#             SeasonUserPointChangeLogOrm.season_id == season.id,
-#             SeasonUserPointChangeLogOrm.user_id == user.id
-#         )
-#         await session.execute(stmt)
-#
-#         if prev_log is not None:
-#             stmt = update(SeasonUserPointOrm).where(
-#                 SeasonUserPointOrm.season_id == season.id,
-#                 SeasonUserPointOrm.user_id == user.id
-#             ).values(
-#                 point=prev_log.create_time
-#             )
-#         else:
-#             stmt = delete(SeasonUserPointOrm).where(
-#                 SeasonUserPointOrm.season_id == season.id,
-#                 SeasonUserPointOrm.user_id == user.id
-#             )
-#         await session.execute(stmt)
-#
-#         await session.commit()
-
-
 async def revert_season_user_point_by_game(game: GameOrm):
     session = data_source.session()
 
@@ -237,11 +212,28 @@ async def revert_season_user_point_by_game(game: GameOrm):
     )
 
     for change_log, user_point in await session.execute(stmt):
-        change_log: SeasonUserPointChangeLogOrm
-        user_point: SeasonUserPointOrm
+        # 判断在此之后是否还变动过PT
+        stmt = select(func.count(SeasonUserPointChangeLogOrm.id)).where(
+            SeasonUserPointChangeLogOrm.season_id == change_log.season_id,
+            SeasonUserPointChangeLogOrm.user_id == change_log.user_id,
+            SeasonUserPointChangeLogOrm.id > change_log.id
+        )
+        cnt = (await session.execute(stmt)).scalar_one()
+
+        if cnt != 0:
+            raise BadRequestError("撤销结算失败，在该对局之后该用户PT发生了改变")
 
         user_point.point -= change_log.change_point
-
         await session.delete(change_log)
 
+        # 若用户只有这一次PT变动，则删除PT记录
+        stmt = select(func.count(SeasonUserPointChangeLogOrm.id)).where(
+            SeasonUserPointChangeLogOrm.season_id == user_point.season_id,
+            SeasonUserPointChangeLogOrm.user_id == user_point.user_id,
+        )
+        cnt = (await session.execute(stmt)).scalar_one()
+
+        if cnt == 0:
+            await session.delete(user_point)
+
     await session.commit()
